@@ -7,11 +7,12 @@ from textual.document._document import (
     Selection,
 )
 from textual.document._document_navigator import DocumentNavigator
+from textual.document._edit import Edit
+from textual.document._history import EditHistory
 from textual.document._languages import BUILTIN_LANGUAGES
 from textual.document._syntax_aware_document import SyntaxAwareDocument
 from textual.document._wrapped_document import WrappedDocument
 from textual.widgets._text_area import (
-    Edit,
     EndColumn,
     Highlight,
     HighlightName,
@@ -27,6 +28,7 @@ __all__ = [
     "DocumentNavigator",
     "Edit",
     "EditResult",
+    "EditHistory",
     "EndColumn",
     "Highlight",
     "HighlightName",
